/*

This code is for the exclusive use of the author, Shane Tolmie

Designed by Shane Tolmie

Reference - see Hi-Tech C FAQ at http://www.keyghost.com/

Microprocessor: 	Microchip PIC12C671, 12C672, 12CE673 or 12CE674

Compiled with:		Hitech-C v7.86pl2, MPLAB v5.00.00

Emulated with:		MPLAB-ICD R4 (using special header to emulate 8-pin 12CE674)


***** PICSTART Plus programming options for PIC12CE674:

First, set #define ICD_EMULATION 0 and under Options..Development mode choose
'MPLab simulator' and 'PIC12CE674'.  Compile, then program with options below
(these should default with the __CONFIG directive in code)

Oscillator:			Internal RC No Clock
Watchdog timer:	On
Poewr Up Timer: On
Code Protect:		Off
Master Clear:		Internal

***** Testing with MPLAB ICD (uses special header for 28-pin 16F877 ICD to
emulate 8-pin 12CE674)

First, #define ICD_EMULATION 1 and under Options..Development mode choose 'MPLAB-
ICD Debugger' and PIC16F877.  Plug 28-pin to 8-pin header into ICD.  Compile,
then:

Setup options for ICD: MPLAB v5.00.00 CONFIG BITS: Device: 16F877, Osc: XT,
Watchdog: off, Power Up Timer: On, Brown Out: off, low voltage program: disable,
code protect data ee: code pro off,flash mem write: no, memory written by eecon,
code protect: off PROGRAM OPTIONS: program mem: tick, config bits:tick, id
locations: tick, eeprom data: notick, erase all before prog: tick, enable debug
mode: tick BASE LINE: com2, 57600, all registers, 10Mhz

Use as per normal - the ICD is now emulating a 8-pin 12CE674

*/

//*****
//if ICD_EMULATION==1, emulates PIC12C672 with PIC16F877 code compiled for ICD
//simply plug in 8-pin PIC12C672 adaptor to 28-pin ICD emulator socket.
//if ICD_EMULATION ==0, compile directly for target processor, PIC12C672
//see top of code for: #define ICD_EMULATION 1	//[user change] [default 1] 0=compile to PIC12C672, 1=emulate with ICD

//*****
//compile for PIC16F876 ICD to emulate target micro PIC12CE674
#if (ICD_EMULATION==1)
	#if defined(_16F877) || defined(_16F874)
		#define _12CE674 USED		//so header file knows what PIC its meant to be
		#include "xc672icd.h"
	#else
		#error Must compile to target 16F877 for MPLAB-ICD emulator or change ICD_EMULATION to 0
	#endif

//*****
//compile directly to target micro
#elif (ICD_EMULATION==0)
	#if defined(_12C671)	|| defined(_12C672)	||\
	    defined(_12CE673)	|| defined(_12CE674)
		#include	<pic.h>
	#else
		#error Must set micro to PIC12Cx67x or change ICD_EMULATION to 1
	#endif
#else
	#error please define ICD_EMULATION as 0 or 1
#endif

//*****
//set correct options for config words in .hex file
#if (ICD_EMULATION==0)
	//compile directly for 12Cx67x
	#if CHIP_NO==0
		__CONFIG(FOSC2);	//if the target is OTP, set code protection flag
	#else
		__CONFIG(FOSC2 | CP1 | CP0);	//if the target is FLASH, *dont* set code protection flag
	#endif
#elif (ICD_EMULATION==1)
	//compile for ICD emulating 12Cx67x
	//__CONFIG(BODEN|FOSC1|PROTECT|BKBUG);
#else
	#error No valid target micro defined.
#endif

